Validation checks used in ensembles — imbalanced-ensemble 0.1.0 documentation

# Validation checks used in ensembles

The `imbalanced_ensemble.utils` module includes various utilities.

`check_eval_datasets`(eval_datasets[, …]) | Check eval_datasets parameter.
`check_eval_metrics`(eval_metrics) | Check parameter eval_metrics.
`check_target_label_and_n_target_samples`(y, …) | Jointly check target_label and n_target_samples parameters.
`check_balancing_schedule`(balancing_schedule) | Check the balancing_schedule parameter.